You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by lo...@apache.org on 2009/07/30 16:35:42 UTC

svn commit: r799288 - in /myfaces/tobago/trunk: core/src/main/java/org/apache/myfaces/tobago/component/ core/src/main/java/org/apache/myfaces/tobago/taglib/component/ core/src/main/java/org/apache/myfaces/tobago/taglib/decl/ extension/tobago-taglib-ext...

Author: lofwyr
Date: Thu Jul 30 14:35:41 2009
New Revision: 799288

URL: http://svn.apache.org/viewvc?rev=799288&view=rev
Log:
enable target attribute for tc:treeNode

Modified:
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/component/AbstractUICommand.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ButtonTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/LinkTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/MenuCommandTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ObjectTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/PageTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/SelectBooleanCommandTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ToolBarCommandTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/TreeNodeTagDeclaration.java
    myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/AbstractCommandTagDeclaration.java
    myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuCheckboxExtensionTag.java
    myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuRadioExtensionTag.java
    myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuBarRenderer.java
    myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java
    myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java
    myfaces/tobago/trunk/theme/standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/CommandRendererHelper.java

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/component/AbstractUICommand.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/component/AbstractUICommand.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/component/AbstractUICommand.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/component/AbstractUICommand.java Thu Jul 30 14:35:41 2009
@@ -95,4 +95,6 @@
   public abstract String getResource();
 
   public abstract String getLink();
+
+  public abstract String getTarget();
 }

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ButtonTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ButtonTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ButtonTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ButtonTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -31,7 +31,6 @@
 import org.apache.myfaces.tobago.taglib.decl.HasLabelAndAccessKey;
 import org.apache.myfaces.tobago.taglib.decl.HasMarkup;
 import org.apache.myfaces.tobago.taglib.decl.HasTabIndex;
-import org.apache.myfaces.tobago.taglib.decl.HasTarget;
 import org.apache.myfaces.tobago.taglib.decl.HasTip;
 import org.apache.myfaces.tobago.taglib.decl.IsDefaultCommand;
 import org.apache.myfaces.tobago.taglib.decl.IsDisabled;
@@ -61,5 +60,5 @@
 public interface ButtonTagDeclaration extends AbstractCommandTagDeclaration,
     HasIdBindingAndRendered, HasLabelAndAccessKey, HasImage,
     IsDisabled, HasCommandType, IsDefaultCommand, HasTip,
-    IsInline, HasTarget, HasMarkup, HasTabIndex, IsGridLayoutComponent {
+    IsInline, HasMarkup, HasTabIndex, IsGridLayoutComponent {
 }

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/LinkTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/LinkTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/LinkTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/LinkTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -31,7 +31,6 @@
 import org.apache.myfaces.tobago.taglib.decl.HasLabelAndAccessKey;
 import org.apache.myfaces.tobago.taglib.decl.HasMarkup;
 import org.apache.myfaces.tobago.taglib.decl.HasTabIndex;
-import org.apache.myfaces.tobago.taglib.decl.HasTarget;
 import org.apache.myfaces.tobago.taglib.decl.HasTip;
 import org.apache.myfaces.tobago.taglib.decl.IsDisabled;
 import org.apache.myfaces.tobago.taglib.decl.IsInline;
@@ -57,5 +56,5 @@
             allowedChildComponenents = "org.apache.myfaces.tobago.Popup")})
 public interface LinkTagDeclaration extends AbstractCommandTagDeclaration,
     HasIdBindingAndRendered, HasLabelAndAccessKey, IsDisabled, IsInline,
-    HasCommandType, HasTarget, HasTip, HasImage, HasMarkup, HasTabIndex {
+    HasCommandType, HasTip, HasImage, HasMarkup, HasTabIndex {
 }

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/MenuCommandTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/MenuCommandTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/MenuCommandTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/MenuCommandTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -25,22 +25,17 @@
 import org.apache.myfaces.tobago.taglib.decl.HasIdBindingAndRendered;
 import org.apache.myfaces.tobago.taglib.decl.HasImage;
 import org.apache.myfaces.tobago.taglib.decl.HasLabelAndAccessKey;
-import org.apache.myfaces.tobago.taglib.decl.HasTarget;
 import org.apache.myfaces.tobago.taglib.decl.IsDisabled;
 
-/*
- * Date: 31.03.2006
- * Time: 21:14:17
- */
 /**
  * Renders a menu item.
  */
 @Tag(name = "menuItem", tagExtraInfoClassName = "org.apache.myfaces.tobago.taglib.component.CommandTagExtraInfo")
 @UIComponentTag(
     uiComponent = "org.apache.myfaces.tobago.component.UIMenuCommand",
-    uiComponentBaseClass = "org.apache.myfaces.tobago.component.AbstractUICommand",
+    uiComponentBaseClass = "org.apache.myfaces.tobago.component.UICommand",
     rendererType = RendererTypes.MENU_COMMAND,
     allowedChildComponenents = "NONE")
 public interface MenuCommandTagDeclaration extends AbstractCommandTagDeclaration,
-    HasIdBindingAndRendered, HasLabelAndAccessKey, IsDisabled, HasCommandType, HasImage, HasTarget {
+    HasIdBindingAndRendered, HasLabelAndAccessKey, IsDisabled, HasCommandType, HasImage {
 }

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ObjectTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ObjectTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ObjectTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ObjectTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -24,6 +24,7 @@
 import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;
 import org.apache.myfaces.tobago.component.RendererTypes;
 import org.apache.myfaces.tobago.taglib.decl.HasId;
+import org.apache.myfaces.tobago.taglib.decl.IsGridLayoutComponent;
 
 /*
  * Date: 02.04.2006
@@ -32,10 +33,10 @@
 @Tag(name = "object", bodyContent = BodyContent.EMPTY)
 @UIComponentTag(
     uiComponent = "org.apache.myfaces.tobago.component.UIObject",
-    uiComponentBaseClass = "javax.faces.component.UIOutput",
+    uiComponentBaseClass = "org.apache.myfaces.tobago.component.AbstractUIOut",
     rendererType = RendererTypes.OBJECT,
     allowedChildComponenents = "NONE")
-public interface ObjectTagDeclaration extends HasId {
+public interface ObjectTagDeclaration extends HasId, IsGridLayoutComponent {
   /**
    * URI to object source
    */

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/PageTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/PageTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/SelectBooleanCommandTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/SelectBooleanCommandTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -17,14 +17,14 @@
  * limitations under the License.
  */
 
-import org.apache.myfaces.tobago.taglib.decl.HasIdBindingAndRendered;
-import org.apache.myfaces.tobago.taglib.decl.HasBooleanValue;
-import org.apache.myfaces.tobago.taglib.decl.AbstractCommandTagDeclaration;
 import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
+import org.apache.myfaces.tobago.taglib.decl.AbstractCommandTagDeclaration;
+import org.apache.myfaces.tobago.taglib.decl.HasBooleanValue;
+import org.apache.myfaces.tobago.taglib.decl.HasIdBindingAndRendered;
 
 @UIComponentTag(
     uiComponent = "org.apache.myfaces.tobago.component.UISelectBooleanCommand",
-    uiComponentBaseClass = "org.apache.myfaces.tobago.component.AbstractUICommand")
+    uiComponentBaseClass = "org.apache.myfaces.tobago.component.UICommand")
 public interface SelectBooleanCommandTagDeclaration extends AbstractCommandTagDeclaration,
     HasIdBindingAndRendered, HasBooleanValue {
 }

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ToolBarCommandTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ToolBarCommandTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ToolBarCommandTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/ToolBarCommandTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -25,7 +25,6 @@
 import org.apache.myfaces.tobago.taglib.decl.HasIdBindingAndRendered;
 import org.apache.myfaces.tobago.taglib.decl.HasImage;
 import org.apache.myfaces.tobago.taglib.decl.HasLabelAndAccessKey;
-import org.apache.myfaces.tobago.taglib.decl.HasTarget;
 import org.apache.myfaces.tobago.taglib.decl.HasTip;
 import org.apache.myfaces.tobago.taglib.decl.IsDisabled;
 
@@ -44,5 +43,5 @@
     rendererType = RendererTypes.BUTTON,
     allowedChildComponenents = "NONE")
 public interface ToolBarCommandTagDeclaration extends AbstractCommandTagDeclaration, HasIdBindingAndRendered,
-    HasLabelAndAccessKey, HasImage, IsDisabled, HasCommandType, HasTip, HasTarget {
+    HasLabelAndAccessKey, HasImage, IsDisabled, HasCommandType, HasTip {
 }

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/TreeNodeTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/TreeNodeTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/TreeNodeTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/TreeNodeTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -31,7 +31,6 @@
 import org.apache.myfaces.tobago.taglib.decl.HasImage;
 import org.apache.myfaces.tobago.taglib.decl.HasLabel;
 import org.apache.myfaces.tobago.taglib.decl.HasMarkup;
-import org.apache.myfaces.tobago.taglib.decl.HasTarget;
 import org.apache.myfaces.tobago.taglib.decl.HasTip;
 import org.apache.myfaces.tobago.taglib.decl.HasValue;
 import org.apache.myfaces.tobago.taglib.decl.IsDisabled;
@@ -53,7 +52,7 @@
     facets = {
         @Facet(name = Facets.ADDENDUM, description = "Displays an additional component to a node.")})
 public interface TreeNodeTagDeclaration
-    extends HasIdBindingAndRendered, HasLabel, HasValue, HasMarkup, HasTip, HasTarget, HasImage, IsDisabled,
+    extends HasIdBindingAndRendered, HasLabel, HasValue, HasMarkup, HasTip, HasImage, IsDisabled,
     AbstractCommandTagDeclaration {
 
   /**

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/AbstractCommandTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/AbstractCommandTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/AbstractCommandTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/AbstractCommandTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -17,11 +17,6 @@
  * limitations under the License.
  */
 
-/*
-* Date: 10.02.2006
-* Time: 22:03:07
-*/
-
 public interface AbstractCommandTagDeclaration extends HasAction, HasActionListener, IsImmediateCommand,
-    HasOnclick, HasLink, HasResource, IsTransition, HasRenderedPartially {
+    HasOnclick, HasLink, HasResource, IsTransition, HasTarget, HasRenderedPartially {
 }

Modified: myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuCheckboxExtensionTag.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuCheckboxExtensionTag.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuCheckboxExtensionTag.java (original)
+++ myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuCheckboxExtensionTag.java Thu Jul 30 14:35:41 2009
@@ -66,6 +66,7 @@
   private String binding;
   private String label;
   private String immediate;
+  private String target;
   private String transition;
   private String renderedPartially;
 
@@ -75,6 +76,7 @@
     menuCommandTag = new MenuItemTag();
     menuCommandTag.setPageContext(pageContext);
     menuCommandTag.setParent(getParent()); // ???
+
     if (rendered != null) {
       menuCommandTag.setRendered(rendered);
     }
@@ -108,6 +110,9 @@
     if (immediate != null) {
       menuCommandTag.setImmediate(immediate);
     }
+    if (target != null) {
+      menuCommandTag.setTarget(target);
+    }
     if (transition != null) {
       menuCommandTag.setTransition(transition);
     }
@@ -202,6 +207,10 @@
     this.immediate = immediate;
   }
 
+  public void setTarget(String target) {
+    this.target = target;
+  }
+
   public void setTransition(String transition) {
     this.transition = transition;
   }
@@ -224,10 +233,12 @@
     binding = null;
     label = null;
     immediate = null;
+    target = null;
     transition = null;
     renderedPartially = null;
     menuCommandTag = null;
     facetTag = null;
     selectBooleanCheckbox = null;
   }
+
 }

Modified: myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuRadioExtensionTag.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuRadioExtensionTag.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuRadioExtensionTag.java (original)
+++ myfaces/tobago/trunk/extension/tobago-taglib-extension/src/main/java/org/apache/myfaces/tobago/taglib/extension/MenuRadioExtensionTag.java Thu Jul 30 14:35:41 2009
@@ -68,6 +68,7 @@
   private String binding;
   private String label;
   private String immediate;
+  private String target;
   private String transition;
   private String converter;
   private String renderedPartially;
@@ -77,7 +78,7 @@
 
     menuCommandTag = new MenuItemTag();
     menuCommandTag.setPageContext(pageContext);
-    menuCommandTag.setParent(getParent());
+    menuCommandTag.setParent(getParent()); // ???
 
     if (rendered != null) {
       menuCommandTag.setRendered(rendered);
@@ -112,6 +113,9 @@
     if (immediate != null) {
       menuCommandTag.setImmediate(immediate);
     }
+    if (target != null) {
+      menuCommandTag.setTarget(target);
+    }
     if (transition != null) {
       menuCommandTag.setTransition(transition);
     }
@@ -211,6 +215,10 @@
     this.immediate = immediate;
   }
 
+  public void setTarget(String target) {
+    this.target = target;
+  }
+
   public void setTransition(String transition) {
     this.transition = transition;
   }
@@ -237,6 +245,7 @@
     binding = null;
     label = null;
     immediate = null;
+    target = null;
     transition = null;
     converter = null;
     renderedPartially = null;

Modified: myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuBarRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuBarRenderer.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuBarRenderer.java (original)
+++ myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/MenuBarRenderer.java Thu Jul 30 14:35:41 2009
@@ -25,11 +25,11 @@
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import static org.apache.myfaces.tobago.TobagoConstants.SUBCOMPONENT_SEP;
-import org.apache.myfaces.tobago.component.AbstractUICommand;
 import org.apache.myfaces.tobago.component.AbstractUIPage;
 import org.apache.myfaces.tobago.component.Attributes;
 import org.apache.myfaces.tobago.component.CreateComponentUtils;
 import org.apache.myfaces.tobago.component.Facets;
+import org.apache.myfaces.tobago.component.UICommand;
 import org.apache.myfaces.tobago.component.UIMenu;
 import org.apache.myfaces.tobago.component.UIMenuCommand;
 import org.apache.myfaces.tobago.component.UIMenuSeparator;
@@ -51,7 +51,6 @@
 import org.apache.myfaces.tobago.util.FastStringWriter;
 import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;
 
-import javax.faces.component.UICommand;
 import javax.faces.component.UIComponent;
 import javax.faces.component.UIForm;
 import javax.faces.component.UIPanel;
@@ -343,8 +342,8 @@
       throws IOException {
     for (Object o : component.getChildren()) {
       UIComponent entry = (UIComponent) o;
-      if (entry instanceof AbstractUICommand) {
-        addMenuEntry(sb, var, facesContext, (AbstractUICommand) entry);
+      if (entry instanceof UICommand) {
+        addMenuEntry(sb, var, facesContext, (UICommand) entry);
       } else if (entry instanceof UIMenuSeparator) {
         addMenuSeparator(sb, var);
       } else if (entry instanceof UIMenu) {
@@ -359,7 +358,7 @@
     return index;
   }
 
-  private void addMenuEntry(StringBuilder sb, String var, FacesContext facesContext, AbstractUICommand command)
+  private void addMenuEntry(StringBuilder sb, String var, FacesContext facesContext, UICommand command)
       throws IOException {
     CommandRendererHelper helper = new CommandRendererHelper(facesContext, command);
     String onclick = helper.getOnclick();

Modified: myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java (original)
+++ myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/ToolBarRendererBase.java Thu Jul 30 14:35:41 2009
@@ -20,11 +20,11 @@
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import static org.apache.myfaces.tobago.TobagoConstants.SUBCOMPONENT_SEP;
-import org.apache.myfaces.tobago.component.AbstractUICommand;
 import org.apache.myfaces.tobago.component.Attributes;
 import org.apache.myfaces.tobago.component.CreateComponentUtils;
 import org.apache.myfaces.tobago.component.Facets;
 import org.apache.myfaces.tobago.component.RendererTypes;
+import org.apache.myfaces.tobago.component.UICommand;
 import org.apache.myfaces.tobago.component.UIMenu;
 import org.apache.myfaces.tobago.component.UIMenuSelectOne;
 import org.apache.myfaces.tobago.component.UISelectBooleanCommand;
@@ -44,7 +44,6 @@
 import org.apache.myfaces.tobago.util.ComponentUtil;
 import org.apache.myfaces.tobago.webapp.TobagoResponseWriter;
 
-import javax.faces.component.UICommand;
 import javax.faces.component.UIComponent;
 import javax.faces.component.UIPanel;
 import javax.faces.component.UISelectBoolean;
@@ -341,17 +340,15 @@
 
   protected abstract String getDivClasses(boolean selected, boolean disabled);
 
-  private String createOnClick(FacesContext facesContext, UIComponent component) {
-    if (component.getFacet(Facets.MENUPOPUP) != null
-        && ((UICommand) component).getAction() == null
-        && ((UICommand) component).getActionListener() == null
-        && ((UICommand) component).getActionListeners().length == 0) {
-      String searchId = component.getClientId(facesContext)
-          + MenuBarRenderer.SEARCH_ID_POSTFIX;
+  private String createOnClick(FacesContext facesContext, UICommand command) {
+    if (command.getFacet(Facets.MENUPOPUP) != null
+        && command.getAction() == null
+        && command.getActionListener() == null
+        && command.getActionListeners().length == 0) {
+      String searchId = command.getClientId(facesContext) + MenuBarRenderer.SEARCH_ID_POSTFIX;
       return "tobagoButtonOpenMenu(this, '" + searchId + "')";
     } else {
-      CommandRendererHelper helper
-          = new CommandRendererHelper(facesContext, (AbstractUICommand) component);
+      CommandRendererHelper helper = new CommandRendererHelper(facesContext, command);
       return helper.getOnclick();
     }
   }

Modified: myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java (original)
+++ myfaces/tobago/trunk/theme/scarborough/src/main/java/org/apache/myfaces/tobago/renderkit/html/scarborough/standard/tag/TreeNodeRenderer.java Thu Jul 30 14:35:41 2009
@@ -156,7 +156,7 @@
       }
     }
 
-    CommandRendererHelper helper = new CommandRendererHelper(facesContext, node);
+    CommandRendererHelper helper = new CommandRendererHelper(facesContext, node, CommandRendererHelper.Tag.ANCHOR);
     TobagoResponseWriter writer = HtmlRendererUtil.getTobagoResponseWriter(facesContext);
 
     if (showRoot || depth != 0) {
@@ -369,6 +369,9 @@
       writer.writeAttribute(HtmlAttributes.ONCLICK, helper.getOnclick(), true); // xxx is escaping required?
       writer.writeAttribute(
           HtmlAttributes.ONFOCUS, "Tobago.Tree.storeMarker(this.parentNode, '" + treeId + "')", false);
+      if (helper.getTarget() != null) {
+        writer.writeAttribute(HtmlAttributes.TARGET, helper.getTarget(), true);
+      }
     }
     if (marked) {
       StyleClasses classes = new StyleClasses();

Modified: myfaces/tobago/trunk/theme/standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/CommandRendererHelper.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/theme/standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/CommandRendererHelper.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================
--- myfaces/tobago/trunk/theme/standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/CommandRendererHelper.java (original)
+++ myfaces/tobago/trunk/theme/standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/util/CommandRendererHelper.java Thu Jul 30 14:35:41 2009
@@ -85,7 +85,7 @@
         if (tag == Tag.ANCHOR) {
           onclick = null;
           href = url;
-          target = ComponentUtil.getStringAttribute(command, Attributes.TARGET);
+          target = command.getTarget();
         } else {
           // TODO target
           onclick = "Tobago.navigateToUrl('" + url + "');";
--- myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/PageTagDeclaration.java (original)
+++ myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/PageTagDeclaration.java Thu Jul 30 14:35:41 2009
@@ -56,10 +56,10 @@
    * <dt>frameset</dt><dd>HTML 4.01 Frameset DTD</dd>
    * </dl>
    * All other values are ignored and no DOCTYPE is set.
    * The default value is 'loose'.
    */
   @TagAttribute
-  @UIComponentTagAttribute(defaultValue = "loose")
+  @UIComponentTagAttribute(defaultValue = "strict")
   void setDoctype(String doctype);
 
   /**
@@ -56,10 +56,10 @@
    * </dl>
    * All other values are ignored and no DOCTYPE is set.
-   * The default value is 'loose'.
+   * The default value is 'strict'.
    */
   @TagAttribute

Modified: myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/SelectBooleanCommandTagDeclaration.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/component/SelectBooleanCommandTagDeclaration.java?rev=799288&r1=799287&r2=799288&view=diff
==============================================================================